@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,13 +8,14 @@
 #define GRAVATARRESOLVURLJOB_H
 
 #include "gravatar_export.h"
-#include <QObject>
-#include <QUrl>
-#include <QPixmap>
 #include <QNetworkReply>
+#include <QObject>
+#include <QPixmap>
+#include <QUrl>
 
 class GravatarResolvUrlJobTest;
-namespace Gravatar {
+namespace Gravatar
+{
 class GravatarResolvUrlJobPrivate;
 class Hash;
 
