@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,9 +7,10 @@
 #ifndef GRAVATARCONFIGURESETTINGSDIALOG_H
 #define GRAVATARCONFIGURESETTINGSDIALOG_H
 
-#include <QDialog>
 #include "gravatar_export.h"
-namespace Gravatar {
+#include <QDialog>
+namespace Gravatar
+{
 class GravatarConfigureSettingsWidget;
 
 /** Gravatar settings dialog. */
